aboutsummaryrefslogtreecommitdiff
path: root/tools/contacts.py
diff options
context:
space:
mode:
authorNavan Chauhan <navanchauhan@gmail.com>2023-10-14 04:39:41 -0600
committerNavan Chauhan <navanchauhan@gmail.com>2023-10-14 04:39:41 -0600
commit704b6407b4e51800376e73fe934a762e94b30d9d (patch)
treef51b5c0bd74abd7b836746f3f2222d282bbd541e /tools/contacts.py
parentd433b974d9f15f9a7ab57ba592a4858e7977726d (diff)
rebased
Diffstat (limited to 'tools/contacts.py')
-rw-r--r--tools/contacts.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/tools/contacts.py b/tools/contacts.py
index 4f4a3be..afdc8a4 100644
--- a/tools/contacts.py
+++ b/tools/contacts.py
@@ -9,11 +9,12 @@ import os
CONTACTS = [
{
"name": "Greg",
- "phone" : os.getenv("TEST_PHONE_NUMBER")
+ "phone" : os.getenv("TEST_PHONE_NUMBER"),
+ "email": "grsi2038@colorado.edu"
}
]
@tool("get_all_contacts")
def get_all_contacts(placeholder: str) -> List[dict]:
"""Returns all contacts in the user's phone book."""
return CONTACTS \ No newline at end of file
@@ -9,11 +9,12 @@ import os
def get_all_contacts(placeholder: str) -> List[dict]:
- """Returns all contacts in the user's phone book."""
+ """Returns all contacts in the user's phone book which includes email and phone numbers."""
return CONTACTS \ No newline at end of file